@@ -65,47 +65,47 @@ _version = ".".join(map(str, max(_versions)))
 _dir = f"app-{_version}"
 APP_DIR = LOCALAPPDATA.joinpath(launcher_dir, _dir )
 
-APP_ICONS = os.path.join(APP_DIR, "Images")
-ICON_APP = os.path.join(APP_ICONS, 'app.png')
-ICON_APP_ERROR = os.path.join(APP_ICONS, 'app_error.png')
-ICON_BROWSER = os.path.join(APP_ICONS, 'browser.png')
-ICON_CALCULATOR = os.path.join(APP_ICONS, 'calculator.png')
-ICON_CANCEL = os.path.join(APP_ICONS, 'cancel.png')
-ICON_CLOSE = os.path.join(APP_ICONS, 'close.png')
-ICON_CMD = os.path.join(APP_ICONS, 'cmd.png')
-ICON_COLOR = os.path.join(APP_ICONS, 'color.png')
-ICON_CONTROL_PANEL = os.path.join(APP_ICONS, 'ControlPanel.png')
-ICON_COPY = os.path.join(APP_ICONS, 'copy.png')
-ICON_DELETE_FILE_FOLDER = os.path.join(APP_ICONS, 'deletefilefolder.png')
-ICON_DISABLE = os.path.join(APP_ICONS, 'disable.png')
-ICON_DOWN = os.path.join(APP_ICONS, 'down.png')
-ICON_EXE = os.path.join(APP_ICONS, 'exe.png')
-ICON_FILE = os.path.join(APP_ICONS, 'file.png')
-ICON_FIND = os.path.join(APP_ICONS, 'find.png')
-ICON_FOLDER = os.path.join(APP_ICONS, 'folder.png')
-ICON_HISTORY = os.path.join(APP_ICONS, 'history.png')
-ICON_IMAGE = os.path.join(APP_ICONS, 'image.png')
-ICON_LOCK = os.path.join(APP_ICONS, 'lock.png')
-ICON_LOGOFF = os.path.join(APP_ICONS, 'logoff.png')
-ICON_OK = os.path.join(APP_ICONS, 'ok.png')
-ICON_OPEN = os.path.join(APP_ICONS, 'open.png')
-ICON_PICTURES = os.path.join(APP_ICONS, 'pictures.png')
-ICON_PLUGIN = os.path.join(APP_ICONS, 'plugin.png')
-ICON_PROGRAM = os.path.join(APP_ICONS, 'program.png')
-ICON_RECYCLEBIN = os.path.join(APP_ICONS, 'recyclebin.png')
-ICON_RESTART = os.path.join(APP_ICONS, 'restart.png')
-ICON_SEARCH = os.path.join(APP_ICONS, 'search.png')
-ICON_SETTINGS = os.path.join(APP_ICONS, 'settings.png')
-ICON_SHELL = os.path.join(APP_ICONS, 'shell.png')
-ICON_SHUTDOWN = os.path.join(APP_ICONS, 'shutdown.png')
-ICON_SLEEP = os.path.join(APP_ICONS, 'sleep.png')
-ICON_UP = os.path.join(APP_ICONS, 'up.png')
-ICON_UPDATE = os.path.join(APP_ICONS, 'update.png')
-ICON_URL = os.path.join(APP_ICONS, 'url.png')
-ICON_USER = os.path.join(APP_ICONS, 'user.png')
-ICON_WARNING = os.path.join(APP_ICONS, 'warning.png')
-ICON_WEB_SEARCH = os.path.join(APP_ICONS, 'web_search.png')
-ICON_WORK = os.path.join(APP_ICONS, 'work.png')
+APP_ICONS = APP_DIR.joinpath("Images")
+ICON_APP = APP_DIR.joinpath('app.png')
+ICON_APP_ERROR = APP_DIR.joinpath(APP_ICONS, 'app_error.png')
+ICON_BROWSER = APP_DIR.joinpath(APP_ICONS, 'browser.png')
+ICON_CALCULATOR = APP_DIR.joinpathn(APP_ICONS, 'calculator.png')
+ICON_CANCEL = APP_DIR.joinpath(APP_ICONS, 'cancel.png')
+ICON_CLOSE = APP_DIR.joinpath(APP_ICONS, 'close.png')
+ICON_CMD = APP_DIR.joinpath(APP_ICONS, 'cmd.png')
+ICON_COLOR = APP_DIR.joinpath('color.png')
+ICON_CONTROL_PANEL = APP_DIR.joinpath('ControlPanel.png')
+ICON_COPY = APP_DIR.joinpath('copy.png')
+ICON_DELETE_FILE_FOLDER = APP_DIR.joinpath('deletefilefolder.png')
+ICON_DISABLE = APP_DIR.joinpath('disable.png')
+ICON_DOWN = APP_DIR.joinpath('down.png')
+ICON_EXE = APP_DIR.joinpath('exe.png')
+ICON_FILE = APP_DIR.joinpath('file.png')
+ICON_FIND = APP_DIR.joinpath('find.png')
+ICON_FOLDER = APP_DIR.joinpath('folder.png')
+ICON_HISTORY = APP_DIR.joinpath('history.png')
+ICON_IMAGE = APP_DIR.joinpath('image.png')
+ICON_LOCK = APP_DIR.joinpath('lock.png')
+ICON_LOGOFF = APP_DIR.joinpath('logoff.png')
+ICON_OK = APP_DIR.joinpath('ok.png')
+ICON_OPEN = APP_DIR.joinpath('open.png')
+ICON_PICTURES = APP_DIR.joinpath('pictures.png')
+ICON_PLUGIN = APP_DIR.joinpath('plugin.png')
+ICON_PROGRAM = APP_DIR.joinpath('program.png')
+ICON_RECYCLEBIN = APP_DIR.joinpath('recyclebin.png')
+ICON_RESTART = APP_DIR.joinpath('restart.png')
+ICON_SEARCH = APP_DIR.joinpath('search.png')
+ICON_SETTINGS = APP_DIR.joinpath('settings.png')
+ICON_SHELL = APP_DIR.joinpath('shell.png')
+ICON_SHUTDOWN = APP_DIR.joinpath('shutdown.png')
+ICON_SLEEP = APP_DIR.joinpath('sleep.png')
+ICON_UP = APP_DIR.joinpath('up.png')
+ICON_UPDATE = APP_DIR.joinpath('update.png')
+ICON_URL = APP_DIR.joinpath('url.png')
+ICON_USER = APP_DIR.joinpath('user.png')
+ICON_WARNING = APP_DIR.joinpath('warning.png')
+ICON_WEB_SEARCH = APP_DIR.joinpath('web_search.png')
+ICON_WORK = APP_DIR.joinpath('work.png')
 
 
 class Flox(Launcher):
